==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Wistia.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$Wistia=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Wistia=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:wistia\.com|wi\.st)\/(?:medias|embed)\/(.*)$/;require=function(_Component){function Wistia(){if(!(this instanceof Wistia))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,_args=Array(_len),_key=0;_key<_len;_key++)_args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(_args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onPlay",function(){var _this$props;return(_this$props=_this.props).onPlay.apply(_this$props,arguments)});_defineProperty(_assertThisInitialized(_this),"onPause",function(){var _this$props2;return(_this$props2=_this.props).onPause.apply(_this$props2,
arguments)});_defineProperty(_assertThisInitialized(_this),"onSeek",function(){var _this$props3;return(_this$props3=_this.props).onSeek.apply(_this$props3,arguments)});_defineProperty(_assertThisInitialized(_this),"onEnded",function(){var _this$props4;return(_this$props4=_this.props).onEnded.apply(_this$props4,arguments)});_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unmute")});
return _this}_inherits(Wistia,_Component);var _super=_createSuper(Wistia);_createClass(Wistia,[{key:"getID",value:function(url){return url&&url.match(MATCH_URL)[1]}},{key:"load",value:function(url){var _this2=this,_this$props5=this.props,playing=_this$props5.playing,muted=_this$props5.muted,controls=_this$props5.controls,_onReady=_this$props5.onReady,config=_this$props5.config;_this$props5=_this$props5.onError;(0,_utils.getSDK)("https://fast.wistia.com/assets/external/E-v1.js","Wistia").then(function(){window._wq=
window._wq||[];window._wq.push({id:_this2.getID(url),options:_objectSpread({autoPlay:playing,silentAutoPlay:"allow",muted,controlsVisibleOnLoad:controls},config.wistia.options),onReady:function(player){_this2.player=player;_this2.unbind();_this2.player.bind("play",_this2.onPlay);_this2.player.bind("pause",_this2.onPause);_this2.player.bind("seek",_this2.onSeek);_this2.player.bind("end",_this2.onEnded);_onReady()}})},_this$props5)}},{key:"unbind",value:function(){this.player.unbind("play",this.onPlay);
this.player.unbind("pause",this.onPause);this.player.unbind("seek",this.onSeek);this.player.unbind("end",this.onEnded)}},{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.unbind();this.callPlayer("remove")}},{key:"seekTo",value:function(seconds){this.callPlayer("time",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("volume",fraction)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("playbackRate",
rate)}},{key:"getDuration",value:function(){return this.callPlayer("duration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("time")}},{key:"getSecondsLoaded",value:function(){return null}},{key:"render",value:function(){var id=this.getID(this.props.url),className="wistia_embed wistia_async_".concat(id);return _react["default"].createElement("div",{key:id,className,style:{width:"100%",height:"100%"}})}}]);return Wistia}(_react.Component);exports.Wistia=require;_defineProperty(require,
"displayName","Wistia");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Wistia.js.map

==> gorilla-notes-0.5.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Wistia.js <==
shadow$provide.module$node_modules$react_player$lib$players$Wistia=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Wistia=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:wistia\.com|wi\.st)\/(?:medias|embed)\/(.*)$/;require=function(_Component){function Wistia(){if(!(this instanceof Wistia))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,_args=Array(_len),_key=0;_key<_len;_key++)_args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(_args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onPlay",function(){var _this$props;return(_this$props=_this.props).onPlay.apply(_this$props,arguments)});_defineProperty(_assertThisInitialized(_this),"onPause",function(){var _this$props2;return(_this$props2=_this.props).onPause.apply(_this$props2,
arguments)});_defineProperty(_assertThisInitialized(_this),"onSeek",function(){var _this$props3;return(_this$props3=_this.props).onSeek.apply(_this$props3,arguments)});_defineProperty(_assertThisInitialized(_this),"onEnded",function(){var _this$props4;return(_this$props4=_this.props).onEnded.apply(_this$props4,arguments)});_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unmute")});
return _this}_inherits(Wistia,_Component);var _super=_createSuper(Wistia);_createClass(Wistia,[{key:"getID",value:function(url){return url&&url.match(MATCH_URL)[1]}},{key:"load",value:function(url){var _this2=this,_this$props5=this.props,playing=_this$props5.playing,muted=_this$props5.muted,controls=_this$props5.controls,_onReady=_this$props5.onReady,config=_this$props5.config;_this$props5=_this$props5.onError;(0,_utils.getSDK)("https://fast.wistia.com/assets/external/E-v1.js","Wistia").then(function(){window._wq=
window._wq||[];window._wq.push({id:_this2.getID(url),options:_objectSpread({autoPlay:playing,silentAutoPlay:"allow",muted:muted,controlsVisibleOnLoad:controls},config.wistia.options),onReady:function(player){_this2.player=player;_this2.unbind();_this2.player.bind("play",_this2.onPlay);_this2.player.bind("pause",_this2.onPause);_this2.player.bind("seek",_this2.onSeek);_this2.player.bind("end",_this2.onEnded);_onReady()}})},_this$props5)}},{key:"unbind",value:function(){this.player.unbind("play",this.onPlay);
this.player.unbind("pause",this.onPause);this.player.unbind("seek",this.onSeek);this.player.unbind("end",this.onEnded)}},{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){this.unbind();this.callPlayer("remove")}},{key:"seekTo",value:function(seconds){this.callPlayer("time",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("volume",fraction)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("playbackRate",
rate)}},{key:"getDuration",value:function(){return this.callPlayer("duration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("time")}},{key:"getSecondsLoaded",value:function(){return null}},{key:"render",value:function(){var id=this.getID(this.props.url),className="wistia_embed wistia_async_".concat(id);return _react["default"].createElement("div",{key:id,className:className,style:{width:"100%",height:"100%"}})}}]);return Wistia}(_react.Component);exports.Wistia=require;_defineProperty(require,
"displayName","Wistia");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Wistia.js.map
